import { ComponentLike } from '@glint/template';
import Component from '@glimmer/component';
import { CellSignature } from '../../../../interfaces/components/models-table/themes/default/cell-signature.interface';
import { CellContentEditSignature } from '../../../../interfaces/components/models-table/themes/default/cell-content-edit-signature.interface';
import { CellContentDisplaySignature } from '../../../../interfaces/components/models-table/themes/default/cell-content-display-signature.interface';
/**
 * Table cell used within {@link Row}.
 *
 * Cell types:
 *
 * * Text. Shows some property value
 * * Route link with record id
 * * Route link with record property value
 * * Custom component
 *
 * See properties {@link Core.ModelsTableColumn.routeName}, {@link Core.ModelsTableColumn.propertyName}, {@link Core.ModelsTableColumn.component}.
 *
 * Usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.Table as |Table|>
 *     <Table.Body as |Body|>
 *       {{#each MT.visibleContent as |record index|}}
 *         <Body.Row @record={{record}} @index={{index}} as |Row|>
 *           {{#each MT.visibleProcessedColumns as |column|}}
 *             <Row.Cell @column={{column}} @index={{index}} as |Cell|/>
 *               {{#if Cell.componentToRender}}
 *                 {{component Cell.componentToRender record=Cell.record column=column index=index}}
 *               {{/if}}
 *               {{! ... }}
 *             </Row.Cell>
 *           {{/each}}
 *         </Body.Row>
 *       {{/each}}
 *       {{! ... }}
 *     </Table.Header>
 *     {{! ... }}
 *   </MT.Table>
 *   {{! .... }}
 * </ModelsTable>
 * ```
 */
export default class Cell extends Component<CellSignature> {
    /**
     * Is this column editable
     *
     * @default false
     */
    get isColumnEditable(): boolean;
    /**
     * Given the mode for a cell (Edit or not) will determine which component to render
     */
    get componentToRender(): ComponentLike<CellContentEditSignature> | ComponentLike<CellContentDisplaySignature> | ComponentLike | null;
    /**
     * @event onClick
     */
    protected onClick(e: Event): void;
}
//# sourceMappingURL=cell.d.ts.map