import Component from '@glimmer/component';
import { GlobalFilterSignature } from '../../../../interfaces/components/models-table/themes/default/global-filter-signature.interface';
/**
 * Global filter element used within {@link Core.ModelsTable | ModelsTable}.
 *
 * Its value is used for all data-items and for each columns {@link Core.ModelsTableColumn.filterField | filterField}.
 *
 * Usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.GlobalFilter />
 *   {{! .... }}
 * </ModelsTable>
 * ```
 *
 * Block usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.GlobalFilter>
 *     {{input value=MT.globalFilter}}
 *     <button disabled={{if MT.globalFilterUsed "disabled"}} {{on "click" this.clearGlobalFilter}}>
 *       Clear Global Filter
 *     </button>
 *   </MT.GlobalFilter>
 *   {{! .... }}
 * </ModelsTable>
 * ```
 */
export default class GlobalFilter extends Component<GlobalFilterSignature> {
    protected elementId: string;
    protected get inputId(): string;
    protected getNewFilterValueFromEvent(e: Event | string): string;
    /**
     * @event noop
     */
    protected noop(): void;
    /**
     * @event updateGlobalFilterString
     */
    protected updateGlobalFilterString(e: Event | string): boolean;
    /**
     * @event clearGlobalFilter
     */
    protected clearGlobalFilter(e: Event): boolean;
}
//# sourceMappingURL=global-filter.d.ts.map