import Component from '@glimmer/component';
import { PaginationNumericSignature } from '../../../../interfaces/components/models-table/themes/default/pagination-numeric-signature.interface';
import { PaginationNumericOption } from '../../../../interfaces/pagination-numeric-option.interface';
/**
 * Numeric navigation used within {@link DefaultTheme.TableFooter | TableFooter}.
 *
 * Usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.Footer as |Footer|>
 *     <Footer.PaginationNumeric />
 *     {{! ... }}
 *   </MT.Footer>
 *   {{! .... }}
 * </ModelsTable>
 * ```
 *
 * Block usage example:
 *
 * ```html
 * <ModelsTable @data={{this.data}} @columns={{this.columns}} as |MT|>
 *   <MT.Footer as |Footer|>
 *     <Footer.PaginationNumeric as |PN|>
 *       {{#each PN.visiblePageNumbers as |page|}}
 *         {{#if page.isLink}}
 *           <button
 *             class="{{MT.themeInstance.paginationNumericItem}} {{if page.isActive MT.themeInstance.paginationNumericItemActive}} {{MT.themeInstance.buttonDefault}}"
 *             {{on "click" (fn MT.goToPage page.label)}}>
 *             {{page.label}}
 *           </button>
 *         {{else}}
 *           <button
 *             type="button"
 *             class="{{MT.themeInstance.buttonDefault}} {{MT.themeInstance.paginationNumericItem}}"
 *             disabled="disabled">
 *             {{page.label}}
 *           </button>
 *         {{/if}}
 *       {{/each}}
 *       <PN.PageNumberSelect />
 *     </Footer.PaginationNumeric>
 *   </MT.Footer>
 * </ModelsTable>
 * ```
 * ModelsTablePaginationNumeric yields references to the following contextual components:
 *
 * * {@link DefaultTheme.Select | PageNumberSelect} - selectbox with list of available pages
 *
 * References to the following properties are yielded:
 *
 * * {@link visiblePageNumbers}
 */
export default class PaginationNumeric extends Component<PaginationNumericSignature> {
    protected elementId: string;
    /**
     * List of links to the page.
     *
     * Used if {@link Core.ModelsTable.useNumericPagination | ModelsTable.useNumericPagination} is `true`.
     *
     * @default []
     */
    protected get visiblePageNumbers(): PaginationNumericOption[];
    protected get inputId(): string;
    /**
     * @event goToPage
     */
    protected goToPage(pageNumber: string): void;
}
//# sourceMappingURL=pagination-numeric.d.ts.map